@@ -1,6 +1,6 @@
-/* $Id: xfce-fileutils.h 17217 2005-08-31 10:19:12Z benny $ */
+/* $Id$ */
 /*-
- * Copyright (c) 2003-2005 Benedikt Meurer <benny@xfce.org>
+ * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>
  * All rights reserved.
  *
  * This library is free software; you can redistribute it and/or
@@ -13,23 +13,29 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Library General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA
  */
 
 #if !defined(LIBXFCE4UTIL_INSIDE_LIBXFCE4UTIL_H) && !defined(LIBXFCE4UTIL_COMPILATION)
 #error "Only <libxfce4util/libxfce4util.h> can be included directly, this file may disappear or change contents"
 #endif
 
-#ifndef __LIBXFCE4UTIL_XFCE_FILEUTILS_H__
-#define __LIBXFCE4UTIL_XFCE_FILEUTILS_H__
+#ifndef __XFCE_FILEUTILS_H__
+#define __XFCE_FILEUTILS_H__
 
 #include <glib.h>
 
-gboolean xfce_mkdirhier (const gchar   *whole_path,
-                         unsigned long  mode,
-                         GError       **error);
+G_BEGIN_DECLS
 
-#endif /* !__LIBXFCE4UTIL_XFCE_FILEUTILS_H__ */
+gboolean  xfce_mkdirhier                    (const gchar *whole_path,
+                                             gulong       mode,
+                                             GError     **error);
+gchar*    xfce_create_shared_thumbnail_path (const gchar *uri,
+                                             const gchar *size);
+
+G_END_DECLS
+
+#endif /* !__XFCE_FILEUTILS_H__ */
