@@ -35,35 +35,7 @@
 #include <glib/gi18n.h>
 #endif
 
-#if !defined(GETTEXT_PACKAGE)
-
-#ifdef gettext
-#undef gettext
-#endif
-#ifdef dgettext
-#undef dgettext
-#endif
-#ifdef dcgettext
-#undef dcgettext
-#endif
-#ifdef ngettext
-#undef ngettext
-#endif
-#ifdef dngettext
-#undef dngettext
-#endif
-#ifdef dcngettext
-#undef dcngettext
-#endif
-
-#define gettext(s)                                            (s)
-#define dgettext(domain,s)                                    (s)
-#define dcgettext(domain,s,type)                              (s)
-#define ngettext(msgid, msgid_plural, n)                      (((n) > 0) ? (msgid) : (msgid_plural))
-#define dngettext(domainname, msgid, msgid_plural, n)         (((n) > 0) ? (msgid) : (msgid_plural))
-#define dcngettext(domainname, msgid, msgid_plural, n, type)  (((n) > 0) ? (msgid) : (msgid_plural))
-
-#endif /* !defined(GETTEXT_PACKAGE) */
+G_BEGIN_DECLS
 
 void                  xfce_textdomain           (const gchar *package,
                                                  const gchar *localedir,
@@ -91,4 +63,6 @@ gchar*                xfce_get_path_localized   (gchar       *dst,
 guint                 xfce_locale_match         (const gchar *locale1,
                                                  const gchar *locale2);
 
+G_END_DECLS
+
 #endif  /* !__XFCE_I18N_H__ */
