@@ -32,11 +32,6 @@
 
 G_BEGIN_DECLS
 
-static inline gboolean xfce_str_is_empty (const gchar *str)
-{
-  return str == NULL || *str == '\0';
-}
-
 const gchar* xfce_version_string (void) G_GNUC_PURE;
 
 const gchar* xfce_get_homedir    (void) G_GNUC_PURE;
@@ -91,7 +86,8 @@ gchar* xfce_expand_variables                 (const gchar  *command,
                                               gchar       **envp) G_GNUC_MALLOC;
 
 void   xfce_append_quoted                    (GString      *string,
-                                              const gchar  *unquoted);
+                                              const gchar  *unquoted)
+  G_GNUC_DEPRECATED_FOR (xfce_g_string_append_quoted());
 
 gchar* xfce_expand_desktop_entry_field_codes (const gchar  *command,
                                               GSList       *uri_list,
